/********************************************************************
 FileName:		main.c
 Dependencies:	See INCLUDES section
 Processor:		PIC18 or PIC24 USB Microcontrollers
 Hardware:		The code is natively intended to be used on the following
 				hardware platforms: PICDEM FS USB Demo Board, 
 				PIC18F87J50 FS USB Plug-In Module, or
 				Explorer 16 + PIC24 USB PIM.  The firmware may be
 				modified for use on other USB platforms by editing the
 				HardwareProfile.h file.
 Complier:  	Microchip C18 (for PIC18) or C30 (for PIC24)
 Company:		Microchip Technology, Inc.

 Software License Agreement:

 The software supplied herewith by Microchip Technology Incorporated
 (the Company) for its PIC Microcontroller is intended and
 supplied to you, the Companys customer, for use solely and
 exclusively on Microchip PIC Microcontroller products. The
 software is owned by the Company and/or its supplier, and is
 protected under applicable copyright laws. All rights are reserved.
 Any use in violation of the foregoing restrictions may subject the
 user to criminal sanctions under applicable laws, as well as to
 civil liability for the breach of the terms and conditions of this
 license.

 THIS SOFTWARE IS PROVIDED IN AN AS IS CONDITION. NO WARRANTIES,
 WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED
 TO, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 PARTICULAR PURPOSE APPLY TO THIS SOFTWARE. THE COMPANY SHALL NOT,
 IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL OR
 CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.

********************************************************************
 File Description:

 Change History:
  Rev   Date         Description
  1.0   11/19/2004   Initial release
  2.1   02/26/2007   Updated for simplicity and to use common
                     coding style
********************************************************************/

/** INCLUDES *******************************************************/
#include <timers.h>

#include "p18f4550.h"
#include "user.h"               

/* You will need to configure these for your oscillator */
#pragma config PLLDIV=5
#pragma config CPUDIV=OSC1_PLL2
#pragma config USBDIV=2
#pragma config FOSC=HSPLL_HS

#pragma config FCMEN=OFF
#pragma config IESO=OFF
#pragma config VREGEN=ON
#pragma config CCP2MX=ON
#pragma config PBADEN=OFF

#pragma config PWRT=ON
#pragma config MCLRE=ON 
#pragma config BOR=ON		
#pragma config BORV=3	
#pragma config WDT=OFF
#pragma config WDTPS=32768
	
#pragma config STVREN=ON
#pragma config LVP=OFF
#pragma config ICPRT= OFF
#pragma config XINST=OFF
#pragma config DEBUG=OFF
#pragma config WRTB=ON
#pragma config LPT1OSC=OFF

/** VARIABLES ******************************************************/
#pragma udata

extern int tmr0_cycle_flag;


/** PRIVATE PROTOTYPES *********************************************/

void LowISR(void);
void HighISR(void);

#pragma code

#pragma interruptlow LowISR
void LowISR(void)
  {
  
  }

#pragma interruptlow HighISR
void HighISR(void)
  {	
  
  	//Check which interrupt flag caused the interrupt.
  	if (INTCONbits.TMR0IF)
  	  {
  	  /* The TMR1 register pair (TMR1H:TMR1L) increments
        * from 0000h to FFFFh and rolls over to 0000h. The
        * Timer1 interrupt, if enabled, is generated on overflow,
        * which is latched in interrupt flag bit, TMR1IF
        * (PIR1<0>). This interrupt can be enabled or disabled
        * by setting or clearing the Timer1 Interrupt Enable bit,
        * TMR1IE (PIE1<0>). 
        */
        
  	  tmr0_cycle_flag = 1;
        
   		INTCONbits.TMR0IF = 0;     // clear the interrupt
  	}
  }

#pragma code lowVector=0x18
void LowVector(void){_asm goto LowISR _endasm}

#pragma code highVector=0x8
void HighVector(void){_asm goto HighISR _endasm}

#pragma code  // Return to default code section


	


#pragma code

void main(void)
  {   
    ADCON1 |= 0x0F;                 // Default all pins to digital
    
  
    User_Init();

    while(1)
      {
        User_Main();     
      }
  }

